@@ -12,6 +12,18 @@ BrowserType: FireFox/Chrome/All
 from enum import Enum, unique
 
 
+@unique
+class VariantType(Enum):
+    Str = 'str'
+    Int = 'int'
+    Bool = 'bool'
+    Set = 'set'
+    List = 'list'
+    Tuple = 'tuple'
+    Dict = 'dict'
+
+
+
 @unique
 class CpuBits(Enum):
     bits64 = 0
@@ -62,4 +74,5 @@ class ProxyType(Enum):
 class BrowserType(Enum):
     FireFox = 0
     Chrome = 1
-    All = 2
\ No newline at end of file
+    All = 2
+
